/*!
  Assertions:
        
  1. No nested comments if any
  2. Selectors ( view types ) must be on the same line
  3. Values will all have quotes if it makes the parsing easier
  4. No special characters in type, property, or ID names
  5. No includes for the first version
  6. No nested quotes
        
  Description:
  This file contains the default theme properties for the view
  framework.

  The views that start with 'F' (e.g., FTextView) are view classes
  that are supported by the view framework. Properties specified for
  these views will be used for all the instances of their classes,
  unless those are overridden by their sub-classes or by their
  instances.

  The following is an at-a-glance view of the view hierarchy used
  by the framework.

  Note that the properties specified for a class, are not inherited by
  sub-classes.

  -------------------------- 
  View Classes
  -------------------------- 

  FView
     FScrollBarView
     FImageView
   	FScrollBarView
     FProgressBarView
        FTextProgressBarView
        FImageProgressBarView
     FTextView
     FCompoundView
        FSplashView
        FScrolledView
        FScrolledTextView
        FListView
        FButtonView
           FCheckBoxView
           FToggleButtonView
           FRadioButtonView
        FRootView 
           FMainScrenView
           FDialogView
              FMenuDialogView
              FInfoDialogView
              FWarningDialogView
              FErrorDialogView
              FQuestionDialogView
              FProgressDialogView
           FMenuView
           FSoftKeyAreaView
        FMenuItemView
	FDialogTitleView

  The views that start with the '#' (pound) symbol are specific
  instances of a particular view class. Therefore, unless overridden,
  they inherit the properties of their ancestors. Properties specified
  for these views are only applied for those instances.

  The following is a list of view instances used in the theme file.
  To specify properties of these views, refer to the view properties
  of their classes.

  --------------------------   --------------------------
  View name                    View class
  --------------------------   --------------------------
  #dialogBackdrop              FRootView

*/

/*!
  Description: Default properties for all the framework views.
*/

FButtonView,
FCheckBoxView,
FCompoundView,
FConfirmDialogView,
FDialogView,
FErrorDialogView,
FImageView,
FInfoDialogView,
FInnerListView,
FListView,
FMainScrenView,
FMenuItemView,
FMenuView,
FMenuDialogView,
FMessageDialogView,
FProgressBarView,
FProgressDialogView,
FQuestionDialogView,
FRadioButtonView,
FRootView,
FScrollBarView,
FScrollBarCornerView,
FScrolledTextView,
FScrolledView,
FSoftKeyAreaView,
FSplashView,
FTextView,
FTextAreaView,
FToggleButtonView,
FView,
FWarningDialogView,
FDialogTitleView,
FStatusBarView,
{
    bg_color:          #ffffff; 
    highlight_color:   #c8c8ff;
    border_color:      #000000; 
    border_visible:    0; 
    bg_visible:        1; 
}

/*************************
 FView
 *************************/

/*!
 Name: FView

 Description: The base class for all the views. No properties should
 be specified for this class. 

 Properties:
   size                              "<width>,<height>"  // number of pixels
   offsets			     "<left>,<top>,<right>,<bottom>" // pixels
   bg_blend_mode                     16 (transparent) | 17 (fixed alpha) | \
                                     18 (alpha bitmap) | 20 (transparent blend)
   blend_mode                        16 (transparent) | 17 (fixed alpha) | \
                                     18 (alpha bitmap) | 20 (transparent blend)
                                       // transparent color = white (#ffffff)
                                       // must be used for the transparent
                                       //  blend mode.
   blend_alpha                       <alpha>  
   bg_color                          <color>  // #rrggbb[aa]
   highlight_color                   <color>  // #rrggbb[aa]
   highlight_color                   <color>  // #rrggbb[aa]
   border_color                      <color>  // #rrggbb[aa]
   bg_visible                        0 | 1    // 0 = invisible, 1 = visible
   border_visible                    0 | 1    // 0 = invisible, 1 = visible
   visible                    	     0 | 1    // visibility of the entire view
                                              // 0 = invisible, 1 = visible
   bg_image_visible                  0 | 1    // 0 = invisible, 1 = visible
   bg_image                          "<resource file>:<resource name>"
   bg_image_highlight                "<resource file>:<resource name>"
*/

/*************************
 FCompoundView
 *************************/

/*!
 Name: FCompoundView

 Description: FCompoundView contains other views and has a strategy
 for laying out the views that it includes. A particular strategy is
 defined for each instance of FCompoundView.

 The view properties specified for this class will affect all the
 direct instances of FCompoundViews. (i.e., properties are not
 inherited by sub-classes.)

 Properties: See FView for properties.  
*/

FCompoundView { 
   bg_color:    #ffffff;
   bg_visible:  1;
}

/*************************
 FViewport
 *************************/

/*!
 Name: FViewport

 Description: This view is used by FScrolledView.

 Properties: See FView.
*/

FViewport { 
  bg_visible:  0; 
}

/*************************
 FImageView
 *************************/

/*!
 Name: FImageView

 Description: A view used for drawing an image.

 Properties: See FView.
*/

FImageView { 
   bg_visible: 1;
}

/*************************
 FListView
 *************************/

/*!
 Name: FListView

 Description: A view that contains a vertical list of views. It is
 used by #channelListView, and #subscriptionAddOnList.

 Properties:
   spacing                            "<pixels>"  // space between list items

 Properties: See FCompoundView.  
*/

FListView { 
   bg_visible:  0;
}

/*!
 Name: FListView > FScrolledView

 Description: A view that is scrolled in the FListView.

 Properties: See FScrolledView
*/

FListView > FScrolledView {
   bg_visible:  0;
}

/*!
 Name: FListView > FScrolledView > FViewport > FCompoundView

 Description: The background of FListView. This affect the color of
 the space between the MFGuideChannelViews in the Guide UI, in cluded in
 the #channelListView (below).

 Properties: See FCompoundView.  
*/

FListView > FScrolledView > FViewport > FCompoundView { 
  bg_visible:   0;
  bg_color:     #e6e6e6;
}

/*!
 Name: FListView > FScrolledView > FViewport > FCompoundView > FTextView

 Description: The background of the menu item in FListView objects that are
 generated by the FListCtrl (i.e., Teh FListView can contain any views. It is
 the FListCtrl that creates FTextView objects as menu items.)

 Properties: See FTextView.
*/

FListView > FScrolledView > FViewport > FCompoundView > FTextView { 
  bg_visible:           1;
  bg_color:             #ffffff;
  bg_image_highlight:   "framework.bar:menu_sl_hl";
  center_tile:          "45,7,65,9";
}


FExpandingListView { 
   bg_visible:  0;
}

FExpandingListView > FScrolledView {
   bg_visible:  0;
}

FExpandingListView > FScrolledView > FViewport > FExpandingListHolder {
   bg_visible:   0;
}

/*************************
 FTextView
 *************************/

/*!
 Name: FTextView, FTextAreaView

 Description: The default properties for all the text views. 

 Properties:
   font                       <fontname>  // QUALCOMM's font format
   text_color                 <color>     // #rrggbg[aa]
   text_color_highlighted     <color>     // #rrggbb[aa]
   h_align                    16 (left) | 32 (center) | 64 (right) 
   v_align                    256 (top) | 512 (middle) | 1024 (bottom) 
                                // deafult: h_align=16, v_align=256
   text_margins		      "<left>,<top>,<right>,<bottom>"
                               // numbers in pixels, default "2,2,2,2"
   (See FView for other properties.)
*/

FTextView, FTextAreaView, FAnimatedTextView { 
   bg_visible:              1; 
   font:                    "MediaFLO,10"; 
   text_color:              #000000; 
   text_color_highlighted:  #000000; 
}

/*************************
 FScrolledTextView
 *************************/

/*!
 Name: FScrolledTextView

 Description: A view for displaying scrolled text. To specify the text
 attributes, use FScrolledTextView > FTextAreaView (below).

 Properties: See FCompoundView.
*/

FScrolledTextView {
   bg_visible:     0;
}

/*!
 Name: FScrolledTextView > FTextAreaView

 Description: A text view that contains the text content in the
 FScrolledTextView.

 Properties: See FTextAreaView.
*/

FScrolledTextView > FTextAreaView { 
   bg_visible:              0; 
   text_color:              #000000; 
   text_color_highlighted:  #000000; 
} 

/*!
 Name: FScrolledTextView > FScrollBarView

 Description: A scrollbar view used by FSCrolledTextView.

 Properties: See FScrollBarView.
*/

FScrolledTextView > FScrollBarView { 
   vscroll_bg_top:        "framework.bar:simple_vscroll_bg_top";
   vscroll_bg_main:       "framework.bar:simple_vscroll_bg_main_r";
   vscroll_bg_bottom:     "framework.bar:simple_vscroll_bg_bottom"; 
   vscroll_slider_top:    "framework.bar:simple_vscroll_slider_main_r";
   vscroll_slider_main:   "framework.bar:simple_vscroll_slider_main_r";
   vscroll_slider_center: "framework.bar:simple_vscroll_slider_main_r"; 
   vscroll_slider_bottom: "framework.bar:simple_vscroll_slider_main_r"; 
}

/*************************
 FRootView
 *************************/

/*!
 Name: FRootView

 Description: The FRootView is a top level view in an application.
 This view has no parent view. It is similar to a window on PCs.

 Properties:
   alpha_enabled                     0 | 1   // False if the view is opaque.
                                             // Default false.
   full_screen                       0 | 1   // True if the view covers the
                                             // entire screen. Default false
   See FCompoundView.  
*/

/* 
FRootView { 
}
*/

/*************************
 FButtonView
 *************************/

/*!
 Name: FButtonView

 Description: The view for constructing buttons. It is used 
 to construct the soft key buttons.
 
 Properties:
                              // These are applied to the button's text.
   h_align                    16 (left) | 32 (center) | 64 (right) 
   v_align                    256 (top) | 512 (middle) | 1024 (bottom) 
   text_margins		      "<left>,<top>,<right>,<bottom>"
                               // numbers in pixels, default "2,2,2,2"
   See FCompoundView
*/

FButtonView { 
   bg_visible:   1; 
}

/*!
 Name: FButtonView > FTextView

 Description: The text label for FButtonView.
 
 Properties: See FComoundView.
*/

FButtonView > FTextView {
   border_visible: 0; 
   bg_visible: 0 
}

/*!
 Name: FButtonView > FImageView

 Description: The extra image for the FButtonView. It is not the
 background image of the button. The image is often used with
 a options soft key label to display a small arrow.
 
 Properties: See FComoundView.
*/

FButtonView > FImageView {
   border_visible: 0;
   bg_visible: 0 
}


/*************************
 FRadioButtonView
 *************************/

/*!
 Name: FRatioButtonView 

 Description: The view class for constructing radio buttons.
 Typically, the same radio button icons are used throughout the
 MediaFLO application; so those are specified at this level.

 Properties: 
   deselected_image_enabled:   "<resource file>:<resource name>"
   selected_image_enabled:     "<resource file>:<resource name>"

   (See FButtonView for other properties.)  
*/

FRadioButtonView { 
   deselected_image_enabled:         "framework.bar:radiobutton_unselected_a"; 
   selected_image_enabled:           "framework.bar:radiobutton_selected_a"; 
}

/*!
 Name: FRadioButtonView > FImageView

 Description: The images view for the FRadioButtonView. The blend mode
 and the background visibility of the images specified in
 FRadioButtonView are specified here. Typically, no other view
 properties are specified here.

 Properties: See FImageView.  
*/

FRadioButtonView > FImageView { 
   blend_mode:        18; 
   bg_visible:        0; 
   border_visible:    0;
}

/*!
 Name: FRadioButtonView > FTextView

 Description: The text properties for the FRadioButtonView are
 specified through this view.

 Properties: See FTextView.  
*/

FRadioButtonView > FTextView {
   size:                   "40,0";
   text_color:             #000000;
   text_color_highlighted: #1511a4; 
   bg_visible:             0; 
}

/*************************
 FToggleButtonView 
 *************************/

/*!
 Name: FToggleButtonView

 Description: FToggleButtonView is a subclass of FButtonView.
 FToggleButtonView is used by the video control buttons.

 Properties: 
   toggle0_image_enabled   "<resource file>:<resource name>"
   toggle1_image_enabled   "<resource file>:<resource name>"
   toggle2_image_enabled   "<resource file>:<resource name>"
   toggle3_image_enabled   "<resource file>:<resource name>"

  (See FButtonView for properties) 
*/

FToggleButtonView { 
   bg_visible:  0; 
}

/*!
 Name: FToggleButtonView > FTextView

 Description: The text properties for FToggleButtonView are specified
 through this view.

 Properties: See FTextView.  
*/

FToggleButtonView > FTextView { 
   bg_visible:             0; 
}

/*!
 Name: FToggleButtonView > FImageView

 Description: The image view of the FToggleButtonView

 Properties: See FImageView.
*/

FToggleButtonView > FImageView { 
   bg_visible:  0; 
}

/*************************
 FCheckBoxView
 *************************/

/*!
 Name: FCheckBoxView 

 Description: The view class for constructing checkboxes.
 
 Properties: See FButtonView for properties
*/

FCheckBoxView { 
   unchecked_image_enabled:  "framework.bar:checkbox_unchecked_a"; 
   checked_image_enabled:    "framework.bar:checkbox_checked_a"; 
   bg_visible:               1;
   bg_image_highlight:       "framework.bar:menu_sl_hl";
   center_tile:              "45,7,65,9";
}

/*!
 Name: FCheckBoxView > FImageView

 Description: The images properties of FCheckBoxView are
 specified through this view. The blend mode and the background
 visibility of the images specified in FCheckBoxView are
 specified here.

 Properties: See FImageView.  
*/

FCheckBoxView > FImageView { 
   border_visible:   0;
   blend_mode:       18; 
   bg_visible:       0; 
}

/*!
 Name: FCheckBoxView > FTextView

 Description: The text properties of FCheckBoxView are
 specified through this view.

 Properties: See FTextView.
*/

FCheckBoxView > FTextView { 
   text_color:             #000000; 
   text_color_highlighted: #1511a4; 
   bg_visible:             0;
}

/*************************
 Pop-up Menu
 *************************/

/*!
 Name: FMenuView

 Description: The view class for constructing pop-up menus. The bg_color
 property should use the same color as the bg_color of 'FMenuView >
 FListView > FScrolledView > FViewport > FCompoundView', as well as
 of 'FMenuItemView > FTextView'.

 Properties:  See FRootView for properties
*/

FMenuView { 
   border_visible:      1; 
   border_color:        #aaaaaa;
   bg_image:            "framework.bar:menu_bg";
}

/*!
 Name: FMenuView > FListView

 Description: A list view that contains menu items. Typically, the
 background is set to transparent.

 Properties: See FListView.
*/

FMenuView > FListView {
   bg_visible: 0;
}

/*!
 Name: FMenuView > FListView > FScrolledView

 Description: A FScrolledView contained by FListView. Typically, the background
 is set to transparent.

 Properties: See FScrolledView
*/

FMenuView > FListView > FScrolledView {
   bg_visible: 0;
}

/*!
 Name: FMenuView > FListView > FScrolledView > FViewport

 Description: A FViewport contained by FScrolled View. Typically, the background
 is set to transparent.

 Properties: See FViewPort.
*/

FMenuView > FListView > FScrolledView > FViewport {
   bg_visible: 0;
}

/*!
 Name: FMenuView > FListView > FScrolledView > FViewport > FCompoundView

 Description: The background color of the pop-up menu are specified
 through this view. This view is exposed between the menu border and
 the menu items.

 Properties: See FCompoundView.  
*/

FMenuView > FListView > FScrolledView > FViewport > FCompoundView {
   bg_visible: 0;
}

/*!
 Name: FMenuItemView

 Description: A generic menu item view that displays a text string. Typically,
 the background is set to transparent.

 Properties: 
*/

FMenuItemView { 
   bg_visible: 0;
}

/*!
 Name: FMenuItemView > FTextView

 Description: The text properties of FMenuItemView are specified
 through this view.

 Properties: See FTextView.  
*/

FMenuItemView > FTextView { 
   bg_visible: 1;
   offsets:			     "2,0,2,0";
   text_margins:                     "4,4,4,4";
   text_color:                       #000000;
   text_color_highlighted:           #1511a4; 
   bg_color:                         #e6e6e6;
   bg_blend_mode:                    16;
   bg_image:                         "framework.bar:popup_transp";
   bg_image_highlight:               "framework.bar:popup_hl";
   center_tile:                      "20,7,40,8";
}

/*************************
 FProgressBarView
 *************************/

/*!
 Name: FProgressBarView

 Description: This view draws a progress bar. No property is set.

 Properties:
   bar_color      <color>    // #rrggbb

  (See FView for other properties.)
*/

FProgressBarView {
   bar_color:      #000000;
}

/*************************
 FImageProgressBarView
 *************************/

/*!
 Name: FImageProgressBarView

 Description: This view draws a fancier progress bar using the images
              below.  The progress bar stretches horizontally but not
              vertically.  It could be extended to stretch vertically
              but that would require an extra 14 images :(

 Properties: 

  Seven images are used to draw the progress bar:

    pb_left, pb_center, pb_right
      These are the background images to the progress. pb_left is used
      only when the progress is at zero.  pb_center is tiled and is
      always drawn no matter what % progress.  pb_right is drawn all
      until 100% progress.

    pb_left_filled, pb_fill_center, pb_right_filled
      These images are used to indicate progress.  Once the progress is
      at 100% all 3 images are used.  'pb_fill_center' is tiled.

    pb_right_filled
      The leading edge of the progess.  This image marks the current
      progress.  It is not used at 0% or 100% progress.

  (See FProgressBarView for other properties.  'bar_color' is not used
   however.)
*/
FImageProgressBarView {
   pb_left:         "framework.bar:pb_left";
   pb_left_filled:  "framework.bar:pb_left_filled";
   pb_center:       "framework.bar:pb_center";
   pb_fill_center:  "framework.bar:pb_fill_center";
   pb_fill_right:   "framework.bar:pb_fill_right";
   pb_right:        "framework.bar:pb_right";
   pb_right_filled: "framework.bar:pb_right_filled";
}

/*************************
 FSoftKeyAreaView
 *************************/

/*
 Name: FSoftKeyAreaView > FButtonView

 Description: The screen area used for displaying the soft key labels.
 It is used to specify the background bitmap or color of the soft key
 area.

 Properties:
   menu_indicator_visible            0 | 1     // 0 = invisible, 1 = visible
   menu_indicator_image              "<resource file>:<resource name>"
   See FRootView.  
*/

FSoftKeyAreaView { 
   size:                  "0,16";
   bg_image:              "framework.bar:softkey_bg";
   center_tile:           "4,8,173,11";
   menu_indicator_image:  "framework.bar:softkey_up_arrow";
   menu_indicator_visible: 1;
}

/*!
 Name: FSoftKeyAreaView > FButtonView

 Description: The properties for the soft key buttons are specified
 through this view. Typically, it is used to specify the soft key
 button's background image. If the soft key label only uses the text
 without a background image, set the bg_visible to 0. It assumes that
 both soft key buttons share the same background image.

 Properties: See FButtonView for properties 
*/

FSoftKeyAreaView > FButtonView {
   size:                "66,12";
   bg_image:            "framework.bar:sk_bg";
   bg_image_highlight:  "framework.bar:sk_bg_hl";
   center_tile:         "7,7,59,8";
   bg_blend_mode:       16;
}

/*!
 Name: #soft1

 Description: The left soft key button in a two soft key button arrangement.

 Properties: See FButtonView.
*/

#soft1 {
   offsets:                          "2,2,0,2";
}

/*!
 Name: #soft2

 Description: The right soft key button in a two soft key button arrangement.

 Properties: See FButtonView.
*/

#soft2 {
   offsets:                          "0,2,2,2";
}

/*!
 Name: #softIconTray

 Description: An icon tray that is aligned with with right soft key

 Properties: See FCompoundView.
*/

#softIconTray {
   offsets:                          "0,0,3,0";
}

/*!
 Name: FSoftKeyAreaView > FButtonView > FImageView { 

 Description: An up arrow used by the Options soft key label.

 Properties: See FImageView.
*/

FSoftKeyAreaView > FButtonView > FImageView { 
   offsets:    "0,0,4,0";
   blend_mode: 16;
   bg_visible: 0
}

/*!
 Name: FSoftKeyAreaView > FButtonView > FTextView 

 Description: The text view used by the soft key labels.  This is part
 of a button view, hence inherits properties that aren't specified
 here from FButtonView > FTextView.

 Properties: See FTextView.
*/

FSoftKeyAreaView > FButtonView > FTextView { 
   font:                   "MediaFLO,10,B"; 
   text_color:             #004276;
   text_color_highlighted: #3330a0;
}

/*!
 Name: FSoftKeyAreaView > FCompoundView

 Description: The compound view used for the middle area of the softkey area

 Properties: See FCompoundView.
*/
FSoftKeyAreaView > FCompoundView { 
   bg_visible: 0;
}

/*!
 Name: FSoftKeyAreaView > FCompoundView > FCompoundView

 Description: The compound view used for the icon tray

 Properties: See FCompoundView.
*/

FSoftKeyAreaView > FCompoundView > FCompoundView{ 
   bg_visible: 0;
}

/*************************
 FScrollBarView
 *************************/

/*! 
 Name: FScrollBarView

 Description: The view class for constructing large scroll bar. This
 scroll bar is primarily used with a full-screen list.  Dialog boxes
 uses a different scroll bar that is simpler. The view is sized based
 on the height and width of the horizontal and vertical scroll bar
 images.

 Properties:
   vscroll_bg_top            "<resource file>:<resource name>"
   vscroll_bg_main           "<resource file>:<resource name>"
   vscroll_bg_bottom         "<resource file>:<resource name>"
   vscroll_slider_top        "<resource file>:<resource name>"
   vscroll_slider_main       "<resource file>:<resource name>"
   vscroll_slider_center     "<resource file>:<resource name>"
   vscroll_slider_bottom     "<resource file>:<resource name>"
   hscroll_bg_top            "<resource file>:<resource name>"
   hscroll_bg_main           "<resource file>:<resource name>"
   hscroll_bg_bottom         "<resource file>:<resource name>"
   hscroll_slider_top        "<resource file>:<resource name>"
   hscroll_slider_main       "<resource file>:<resource name>"
   hscroll_slider_center     "<resource file>:<resource name>"
   hscroll_slider_bottom     "<resource file>:<resource name>" 
   auto_size                 1|0 (1 for true or 0 for false, true default)

   (See FCompoundView for other properties.)
*/

FScrollBarView {
   vscroll_bg_top:        "framework.bar:vscroll_bg_top"; 
   vscroll_bg_main:       "framework.bar:vscroll_bg_main_r"; 
   vscroll_bg_bottom:     "framework.bar:vscroll_bg_bottom"; 
   vscroll_slider_top:    "framework.bar:vscroll_slider_top"; 
   vscroll_slider_main:   "framework.bar:vscroll_slider_main_r"; 
   vscroll_slider_center: "framework.bar:vscroll_slider_center"; 
   vscroll_slider_bottom: "framework.bar:vscroll_slider_bottom"; 

   hscroll_bg_left:       "framework.bar:hscroll_bg_left";
   hscroll_bg_main:       "framework.bar:hscroll_bg_main_r";
   hscroll_bg_right:      "framework.bar:hscroll_bg_right";
   hscroll_slider_left:   "framework.bar:hscroll_slider_left";
   hscroll_slider_main:   "framework.bar:hscroll_slider_main_r";
   hscroll_slider_center: "framework.bar:hscroll_slider_center";
   hscroll_slider_right:  "framework.bar:hscroll_slider_right";
}

/*! 
 Name: FScrollBarCornerView

 Description: The view class for constructing the corner where two 
 FScrollBarViews intersect.

 Properties:
   image                     "<resource file>:<resource name>"
   auto_size                 1|0 (1 for true or 0 for false, true default)

   (See FImageView for other properties.)
*/

FScrollBarCornerView {
   image:         	  "framework.bar:scroll_corner"; 
}

/*************************
 FStatusBarView
 *************************/
/*!
 Name: FStatusBarView
 Description:  A status bar view is an area of the screen available to display
               status, usually text messages.  You'll often find one at the
	       bottom of a screen.
*/
FStatusBarView {
   size:             "0,24";
}

FStatusBarView > FTextAreaView {
   text_margins:     "2,2,2,2";
   text_color:       #000000;
   bg_visible:       0;   
}

/*************************
 FDialogView
 *************************/

/*!
 Name: FDialogTitleView

 Description: The properties for the dialog's title area is specified
 through this view. The size is set to a specific value for this view
 because of the unique size of the dialog background images.

 Properties: See FCompoundView
*/

FDialogTitleView {
   size:                "0,25"; 
   bg_visible:          1;
   bg_image:            "framework.bar:dialog_title";
   center_tile:         "10,0,20,38";
}

/*!
 Name: FDialogTitleView > FTextView

 Description: The text view inside the dialog title view.
 
 Properties: See FTextView.  
*/

FDialogTitleView > FTextView { 
   size:            "0,22"; 
   h_align:         32;
   v_align:         512;
   text_margins:    "2,3,2,3";
   font:            "MediaFLO,10,B"; 
   text_color:      #000000; 
   bg_visible:      0; 
}

/*************************
 FMenuDialogView
 *************************/

/*!
 Name: FMenuDialogView
 Description: A generic dialog for holding list of FMenuDialogItemViews.

 Hierarchy:
 FMenuDialogView ----------> The dialog view
   FDialogTitleView -------> The title of the dialog
   FCompoundView ----------> The main area of the dialog
     FTextAreaView --------> The information text view of the dialog
     FListView ------------> The list view holding the menu items

 Properties: See FDialogView, and sub views below.
*/

/*!
 Name: FMenuDialogView > FDialogTitleView

 Description: The title area of the FMenuDialogView.

 Properties: See FDialogTitleView.
*/

FMenuDialogView > FDialogTitleView {
   size:                "0,0";
   bg_visible:          1;
   bg_image:            "framework.bar:title_background";
   center_tile:         "4,8,173,11";
}

/*!
 Name: FMenuDialogView > FDialogTitleView > FTextView 

 Description: The text inside the title area.

 Properties: See FTextView.
*/
FMenuDialogView > FDialogTitleView > FTextView { 
   size:            "0,0";
   text_color:      #e6e6e6; 
}

/*!
 Name: FMenuDialogView > FCompoundView

 Description: The background of the FMenuDialogView.

 Properties: See FCompoundView.
*/

FMenuDialogView > FCompoundView {
   bg_color:        #ffffff;
   bg_visible:      1;
}

/*!
 Name: FMenuDialogView > FCompoundView > FTextAreaView

 Description: The Information text area view of the FMenuDialogView.

 Properties: See FTextAreaView.
*/

FMenuDialogView > FCompoundView > FTextAreaView {
   offsets:                     "1,1,1,1";
   text_margins:                "5,5,5,5";
   border_visible:              1;
}

/*!
 Name: FMenuDialogView > FCompoundView > FListView

 Description: The list view of the FMenuDialogView.

 Properties: See FListView.
*/

FMenuDialogView > FCompoundView > FListView {
   offsets:                     "2,2,2,2";
   spacing:                     1;
}

/*!
 Name: FMessageDialogView

 Description: A special dialog box for displaying a program note.

 Properties: See FDialogView, and sub views below.
*/
FMessageDialogView {
   border_visible:  1;
   border_color:    #206986;
}

/*!
 Name: FConfirmDialogView

 Description: A non-fullscreen dialog for providing the user with
 information.

 Properties: See FDialogView.
*/

FConfirmDialogView {
   border_visible:  1;
   border_color:    #206986;
}

/*!
 Name: FInfoDialogView

 Description: A non-fullscreen dialog for providing the user with
 information.

 Properties: See FDialogView.
*/

FInfoDialogView {
   border_visible:  1;
   border_color:    #206986;
}

/*!
 Name: FWarningDialogView

 Description: A non-fullscreen dialog for providing the user with
 a warning.

 Properties: See FDialogView
*/

FWarningDialogView {
   border_visible:  1;
   border_color:    #206986;
}

/*!
 Name: FErrorDialogView

 Description: A non-fullscreen dialog for displaying an error message.

 Properties:
*/

FErrorDialogView {
   border_visible:  1;
   border_color:    #206986;
}

/*!
 Name: FQuestionDialogView

 Description: A non-fullscreen dialog for displaying a question. Currently,
 there's no difference between the warning and the question dialog.

 Properties: See FDialogView.
*/

FQuestionDialogView {
   border_visible:  1;
   border_color:    #206986;
}

/*!
 Name: FProgressDialogView

 Description: A non-fullscreen dialog for displaying an indeterminate progress.

 Properties: See FDialogView.
*/

FProgressDialogView {
   border_visible:  1;
   border_color:    #206986;
}

/*!
 Name: FxxxDialogView > DialogTitleView

 Description:  The properties for the title area of the common system
 dialogs.

 Properties: See DialogTitleView
*/

FInfoDialogView > FDialogTitleView {
   size:                "0,38"; 
   bg_image:            "framework.bar:info_dialog_title";
   center_tile:         "60,0,80,38";
}

FWarningDialogView > FDialogTitleView {
   size:                "0,38"; 
   bg_image:            "framework.bar:warning_dialog_title";
   center_tile:         "60,0,80,38";
}

FQuestionDialogView > FDialogTitleView {
   size:                "0,38"; 
   bg_image:            "framework.bar:warning_dialog_title";
   center_tile:         "60,0,80,38";
}

FProgressDialogView > FDialogTitleView {
   size:                "0,38"; 
   bg_image:            "framework.bar:progress_dialog_title";
   center_tile:         "60,0,80,38";
}

FErrorDialogView > FDialogTitleView {
   size:                "0,38"; 
   bg_image:            "framework.bar:error_dialog_title";
   center_tile:         "60,0,80,38";
}

/*!
 Name: FxxxDialogView > FDialogTitleView > FTextView

 Description:  The text inside the dialog title areas for the common system
 dialogs.

 Properties: See FTextView
*/

FInfoDialogView > FDialogTitleView > FTextView { 
   offsets:         "38,0,0,0";
   h_align:         16;
}

FWarningDialogView > FDialogTitleView > FTextView { 
   offsets:         "38,0,0,0";
   h_align:         16;
}

FQuestionDialogView > FDialogTitleView > FTextView { 
   offsets:         "38,0,0,0";
   h_align:         16;
}

FErrorDialogView > FDialogTitleView > FTextView { 
   offsets:         "38,0,0,0";
   h_align:         16;
}

FProgressDialogView > FDialogTitleView > FTextView { 
   offsets:         "38,0,0,0";
   h_align:         16;
}

/*!
 Name: FConfirmDialogView > FCompoundView

 Description: The dialog box background for the information dialog.
 
 Properties: See FCompoundView for properties
*/

FConfirmDialogView > FCompoundView {
   bg_visible:          1; 
   bg_color:            #e6e6e6;	
   bg_image:            "framework.bar:msg_dialog_bg";
}

/*!
 Name: FInfoDialogView > FCompoundView

 Description: The dialog box background for the information dialog.
 
 Properties: See FCompoundView for properties
*/

FInfoDialogView > FCompoundView {
   bg_visible:          1; 
   bg_color:            #e6e6e6;	
   bg_image:            "framework.bar:msg_dialog_bg";
}

/*!
 Name: FWarningDialogView > FCompoundView

 Description: The dialog box background for the warning dialog.

 Properties: See FCompoundView.
*/

FWarningDialogView > FCompoundView {
   bg_visible:          1; 
   bg_color:            #e6e6e6;
   bg_image:            "framework.bar:msg_dialog_bg";
}

/*!
 Name: FQuestionDialogView > FCompoundView

 Description: The dialog box background for the question dialog.

 Properties: See FCompoundView
*/

FQuestionDialogView > FCompoundView {
   bg_visible:          1; 
   bg_color:            #e6e6e6;
   bg_image:            "framework.bar:msg_dialog_bg";
}

/*!
 Name: FErrorDialogView > FCompoundView

 Description: The dialog box background for the error dialog.

 Properties: See FCompoundView.
*/

FErrorDialogView > FCompoundView {
   bg_visible:          1; 
   bg_color:            #e6e6e6;
   bg_image:            "framework.bar:msg_dialog_bg";
}

/*!
 Name: FProgressDialogView > FCompoundView {

 Description: The dialog box background for the error dialog.

 Properties: See FCompoundView
*/

FProgressDialogView > FCompoundView {
   bg_visible:          1; 
   bg_color:            #e6e6e6;
   bg_image:            "framework.bar:msg_dialog_bg";
}

/*!
 Name: FMessageDialogView > FCompoundView

 Description: The background of the program note dialog box.

 Properties: See FCompoundView
*/
FMessageDialogView > FCompoundView {
   bg_visible:          1;
   bg_color:            #e6e6e6;
   bg_image:            "framework.bar:msg_dialog_bg";
}

/*!
 Name: F<xxx>DialogView > FCompoundView > FScrolledTextView

 Description: The scrolled text view that holds the text message.

 Properties: See FScrolledTextView
*/
FMessageDialogView > FCompoundView > FScrolledTextView {
   offsets:             "15,5,15,10";
   bg_visible:          0;
}

FConfirmDialogView > FCompoundView > FScrolledTextView {
   offsets:             "15,15,15,15";
   bg_visible:          0;
}

FInfoDialogView > FCompoundView > FScrolledTextView {
   offsets:             "15,5,15,10";
   bg_visible:          0;
}

FWarningDialogView > FCompoundView > FScrolledTextView {
   offsets:             "15,5,15,10";
   bg_visible:          0;
}

FQuestionDialogView > FCompoundView > FScrolledTextView {
   offsets:             "15,5,15,10";
   bg_visible:          0;
}

FErrorDialogView > FCompoundView > FScrolledTextView {
   offsets:             "15,5,15,10";
   bg_visible:          0;
}

/*!
  The extra offset at the bottom must include the height of the progress
  animation image.
*/
FProgressDialogView > FCompoundView > FScrolledTextView {
   offsets:             "15,5,15,35";
   bg_visible:          0;
}

/*!
 Name: F<xxx>DialogView > FCompoundView > FScrolledTextView > FTextAreaView

 Description: Contains the text for the messsage.

 Properties: See FTextAreaView
*/
FMessageDialogView > FCompoundView > FScrolledTextView > FTextAreaView { 
   h_align:          16;
   v_align:          512;
   text_color:       #000000; 
   bg_visible:       0; 
}

/*!
  The text for the confirmation dialog is centered.
*/
FConfirmDialogView > FCompoundView > FScrolledTextView > FTextAreaView { 
   h_align:      32;
   v_align:      512;
   text_color:   #000000;
   bg_visible:   0;
}

FInfoDialogView > FCompoundView > FScrolledTextView > FTextAreaView { 
   h_align:      16;
   v_align:      512;
   text_color:   #000000;
   bg_visible:   0;
}

FWarningDialogView > FCompoundView > FScrolledTextView > FTextAreaView { 
   h_align:      16;
   v_align:      512;
   text_color:   #000000;
   bg_visible:   0;
}

FQuestionDialogView > FCompoundView > FScrolledTextView > FTextAreaView { 
   h_align:      16;
   v_align:      512;
   text_color:   #000000;
   bg_visible:   0;
}

FErrorDialogView > FCompoundView > FScrolledTextView > FTextAreaView { 
   h_align:      16;
   v_align:      512;
   text_color:   #000000;
   bg_visible:   0;
}

FProgressDialogView > FCompoundView > FScrolledTextView > FTextAreaView { 
   h_align:      16;
   v_align:      512;
   text_color:   #000000;
   bg_visible:   0;
}

/*!
 Name: #progressDialogProgressImage

 Description: The image for the indeterminate progress dialog.

 Properties: See FImageView.
*/
#progressDialogProgressImage {
   offsets:             "0,0,0,10";
   size:                "20,20";
   blend_mode:          18;
   image:               "framework.bar:progress_animation";
   animation:           "strip,8,20,8";
   bg_visible:          0;
}

/*!
 Name: #dialogBackdrop

 Description: The translucent background for non-full-screen 
 dialog boxes.

 Properties: See FCompoundView.
*/

#dialogBackdrop { 
   bg_visible:      1; 
   bg_color:        #0000004c; 
   bg_blend_mode:   17; 
}


